summaryrefslogtreecommitdiff
path: root/jenkins-helpers.sh
diff options
context:
space:
mode:
Diffstat (limited to 'jenkins-helpers.sh')
-rw-r--r--jenkins-helpers.sh12
1 files changed, 5 insertions, 7 deletions
diff --git a/jenkins-helpers.sh b/jenkins-helpers.sh
index 066aacb9..1915f66c 100644
--- a/jenkins-helpers.sh
+++ b/jenkins-helpers.sh
@@ -545,17 +545,15 @@ clone_or_update_repo ()
)
}
-# Clone or update a baseline git repo
-# $1 -- repo directory
-# $2 -- branch to checkout
-# $3 -- Whether to make the new remote read-only or read-write.
-clone_baseline_repo ()
+# Print baseline git repo
+# $1 -- project name
+# $3 -- whether to make the new remote read-only or read-write.
+print_baseline_repo ()
{
(
set -euf -o pipefail
local dir="$1"
- local branch="$2"
local read_only="$3"
local repo
@@ -575,7 +573,7 @@ clone_baseline_repo ()
url="ssh://$url"
fi
- clone_or_update_repo "$dir" "$branch" "$url" auto "$branch" baseline
+ echo "$url"
)
}